@@ -375,6 +375,9 @@ def test_3848():
         # Takes 40m on Github.
         print(f'test_3848(): not running on valgrind because very slow.', flush=1)
         return
+    if platform.python_implementation() == 'GraalVM':
+        print(f'test_3848(): Not running because slow on GraalVM.')
+        return
     path = os.path.normpath(f'{__file__}/../../tests/resources/test_3848.pdf')
     with pymupdf.open(path) as document:
         for i in range(len(document)):
@@ -579,3 +582,49 @@ def test_4445():
     wt = pymupdf.TOOLS.mupdf_warnings()
     print(f'{wt=}')
     assert wt == 'broken xref subsection, proceeding anyway.\nTrailer Size is off-by-one. Ignoring.'
+
+
+def test_3806():
+    print()
+    print(f'{pymupdf.mupdf_version=}')
+    path = os.path.normpath(f'{__file__}/../../tests/resources/test_3806.pdf')
+    path_png_expected = os.path.normpath(f'{__file__}/../../tests/resources/test_3806-expected.png')
+    path_png = os.path.normpath(f'{__file__}/../../tests/test_3806.png')
+    
+    with pymupdf.open(path) as document:
+        pixmap = document[0].get_pixmap()
+        pixmap.save(path_png)
+        rms = gentle_compare.pixmaps_rms(path_png_expected, pixmap)
+        print(f'{rms=}')
+        if pymupdf.mupdf_version_tuple >= (1, 26, 6):
+            assert rms < 0.1
+        else:
+            assert rms > 50
+
+
+def test_4388():
+    print()
+    path_BOZ1 = os.path.normpath(f'{__file__}/../../tests/resources/test_4388_BOZ1.pdf')
+    path_BUL1 = os.path.normpath(f'{__file__}/../../tests/resources/test_4388_BUL1.pdf')
+    path_correct = os.path.normpath(f'{__file__}/../../tests/resources/test_4388_BUL1.pdf.correct.png')
+    path_test = os.path.normpath(f'{__file__}/../../tests/resources/test_4388_BUL1.pdf.test.png')
+    
+    with pymupdf.open(path_BUL1) as bul:
+        pixmap_correct = bul.load_page(0).get_pixmap()
+        pixmap_correct.save(path_correct)
+    
+    pymupdf.TOOLS.store_shrink(100)
+    
+    with pymupdf.open(path_BOZ1) as boz:
+        boz.load_page(0).get_pixmap()
+
+    with pymupdf.open(path_BUL1) as bul:
+        pixmap_test = bul.load_page(0).get_pixmap()
+        pixmap_test.save(path_test)
+
+    rms = gentle_compare.pixmaps_rms(pixmap_correct, pixmap_test)
+    print(f'{rms=}')
+    if pymupdf.mupdf_version_tuple >= (1, 26, 6):
+        assert rms == 0
+    else:
+        assert rms >= 10
